@@ -64,16 +64,16 @@ func NewCmdSetDefault(f *cmdutil.Factory, runF func(*SetDefaultOptions) error) *
 		Short: "Configure default repository for this directory",
 		Long:  explainer(),
 		Example: heredoc.Doc(`
-			Interactively select a default repository:
+			# Interactively select a default repository
 			$ gh repo set-default
 
-			Set a repository explicitly:
+			# Set a repository explicitly
 			$ gh repo set-default owner/repo
 
-			View the current default repository:
+			# View the current default repository
 			$ gh repo set-default --view
 
-			Show more repository options in the interactive picker:
+			# Show more repository options in the interactive picker
 			$ git remote add newrepo https://github.com/owner/repo
 			$ gh repo set-default
 		`),
@@ -105,8 +105,8 @@ func NewCmdSetDefault(f *cmdutil.Factory, runF func(*SetDefaultOptions) error) *
 		},
 	}
 
-	cmd.Flags().BoolVarP(&opts.ViewMode, "view", "v", false, "view the current default repository")
-	cmd.Flags().BoolVarP(&opts.UnsetMode, "unset", "u", false, "unset the current default repository")
+	cmd.Flags().BoolVarP(&opts.ViewMode, "view", "v", false, "View the current default repository")
+	cmd.Flags().BoolVarP(&opts.UnsetMode, "unset", "u", false, "Unset the current default repository")
 
 	return cmd
 }
@@ -119,15 +119,18 @@ func setDefaultRun(opts *SetDefaultOptions) error {
 
 	currentDefaultRepo, _ := remotes.ResolvedRemote()
 
+	cs := opts.IO.ColorScheme()
+
 	if opts.ViewMode {
 		if currentDefaultRepo != nil {
 			fmt.Fprintln(opts.IO.Out, displayRemoteRepoName(currentDefaultRepo))
 		} else {
-			fmt.Fprintln(opts.IO.ErrOut, "no default repository has been set; use `gh repo set-default` to select one")
+			fmt.Fprintf(opts.IO.ErrOut,
+				"%s No default remote repository has been set. To learn more about the default repository, run: gh repo set-default --help\n",
+				cs.FailureIcon())
 		}
 		return nil
 	}
-	cs := opts.IO.ColorScheme()
 
 	if opts.UnsetMode {
 		var msg string
